@@ -29,18 +29,21 @@ class DeprecatedRuntimeEol(DeprecatedRuntime):
         runtime = self.deprecated_runtimes.get(runtime_value)
         if runtime:
             if (
-                datetime.strptime(runtime["eol"], "%Y-%m-%d") < self.current_date
-                and datetime.strptime(runtime["deprecated"], "%Y-%m-%d")
+                datetime.strptime(runtime["deprecated"], "%Y-%m-%d") < self.current_date
+                and datetime.strptime(runtime["create-block"], "%Y-%m-%d")
+                > self.current_date
+                and datetime.strptime(runtime["update-block"], "%Y-%m-%d")
                 > self.current_date
             ):
-                message = "EOL runtime ({0}) specified. Runtime is EOL since {1} and updating will be disabled at {2}. Please consider updating to {3}"
+                message = "Runtime ({0}) was deprecated on {1}. Creation will be disabled on {2} and update on {3}. Please consider updating to {4}"
                 matches.append(
                     RuleMatch(
                         path,
                         message.format(
                             runtime_value,
-                            runtime["eol"],
                             runtime["deprecated"],
+                            runtime["create-block"],
+                            runtime["update-block"],
                             runtime["successor"],
                         ),
                     )
